@@ -11,7 +11,7 @@ use MIME::Base64;
 use Lemonldap::NG::Portal::SharedConf;    # inherits
 use Lemonldap::NG::Portal::_SAML;         # inherits
 
-our $VERSION = '0.992';
+our $VERSION = '1.0.0';
 our @ISA = qw(Lemonldap::NG::Portal::_SAML Lemonldap::NG::Portal::SharedConf);
 
 ## @method int process()
@@ -176,7 +176,7 @@ Main method.
 =head1 SEE ALSO
 
 L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Portal::SharedConf>, L<CGI>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -185,7 +185,7 @@ Clement Oudot, E<lt>clement@oodo.netE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -197,7 +197,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 Copyright (C) 2010 by Clement Oudot, E<lt>clement@oodo.netE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
